@@ -31,6 +31,8 @@ def serve_api_default(config: Config, path: Path) -> None:
     """
     Depending on if we're running gunicorn (for WSGI websites) or daphne
     (for ASGI websites), generate and run the appropriate command line.
+    There is also a granian option for ASGI both WSGI, which will become the
+    default in the future, when Gunicorn/Daphne will be removed.
 
     We bind on 0.0.0.0 because we need the flow to be accessible from outside
     the container.
@@ -57,13 +59,16 @@ def serve_api_default(config: Config, path: Path) -> None:
             )
 
         printer.handover(
-            f"Starting gunicorn (port {port})",
+            f"Starting gunicorn (port {port}). WARNING: Gunicorn is deprecated and will be removed in the future. Use granian instead.",
             path,
             [
                 "poetry",
                 "run",
                 *["python", "-m", "gunicorn"],
+                *["--enable-stdio-inheritance"],
+                *["--capture-output"],
                 *["--bind", f"0.0.0.0:{port}"],
+                *["--access-logfile", "-"],
                 *["--log-file", "-"],
                 *["--worker-tmp-dir", "/dev/shm"],
                 *["--threads", "10"],
@@ -79,7 +84,7 @@ def serve_api_default(config: Config, path: Path) -> None:
             )
 
         printer.handover(
-            f"Starting daphne (port {port})",
+            f"Starting daphne (port {port}). WARNING: Daphne is deprecated and will be removed in the future. Use granian instead.",
             path,
             [
                 "poetry",
@@ -90,6 +95,34 @@ def serve_api_default(config: Config, path: Path) -> None:
                 config.project.asgi,
             ],
         )
+    elif config.project.server == "granian":
+        run_command = [
+            "poetry",
+            "run",
+            *["python", "-m", "granian"],
+            *["--host", "0.0.0.0"],
+            *["--port", f"{port}"],
+        ]
+        if config.project.asgi:
+            printer.handover(
+                f"Starting granian ASGI (port {port})",
+                path,
+                [
+                    *run_command,
+                    *["--interface", "asgi"],
+                    config.project.asgi,
+                ],
+            )
+        else:
+            printer.handover(
+                f"Starting granian WSGI (port {port})",
+                path,
+                [
+                    *run_command,
+                    *["--interface", "wsgi"],
+                    config.project.wsgi,
+                ],
+            )
     else:
         raise UserException(f"Unknown server: {config.project.server}")
 
@@ -182,7 +215,9 @@ def serve_api(config: Config, path: Path, variant: str) -> None:
 
 def serve_front(path: Path) -> None:
     """
-    Simply start the Nuxt server.
+    Start the front server.
+    SvelteKit and Nuxt are both supported, so we check if the project has a
+    SvelteKit `build` directory, and if not, we use Nuxt's `output` directory.
 
     We bind on 0.0.0.0 because we need the flow to be accessible from outside
     the container.
@@ -195,20 +230,27 @@ def serve_front(path: Path) -> None:
 
     printer = Printer.instance()
 
-    printer.chapter("Serving Nuxt project")
+    printer.chapter("Serving front project")
+
+    nuxt_path = ".output/server/index.mjs"
+    sveltekit_path = "build"
+
     port = getenv("PORT", "3000")
 
-    printer.handover(
-        "Running Nuxt server",
-        path,
-        [
-            *["npm", "run"],
-            "start",
-            "--",
-            *["--hostname", "0.0.0.0"],
-            *["--port", f"{port}"],
-        ],
-    )
+    printer.env_patch.update({"HOST": "0.0.0.0", "PORT": f"{port}"})
+
+    if (path / nuxt_path).exists():
+        printer.handover(
+            "Running Nuxt server",
+            path,
+            ["node", nuxt_path],
+        )
+    else:
+        printer.handover(
+            "Running SvelteKit server",
+            path,
+            ["node", sveltekit_path],
+        )
 
 
 def serve(config: Config, path: Path, variant: str) -> None:
